@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2015-2020, Exa Analytics Development Team
+# Copyright (c) 2015-2022, Exa Analytics Development Team
 # Distributed under the terms of the Apache License 2.0
 """
 Version Information
@@ -8,7 +8,7 @@ The version can be checked using the following command:
 
 .. code-block:: Python
 
-    exa.__verion__
+    exatomic.__verion__
 """
 import os
 
