@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2015-2020, Exa Analytics Development Team
+# Copyright (c) 2015-2022, Exa Analytics Development Team
 # Distributed under the terms of the Apache License 2.0
 """
 ADF Composite Output
@@ -15,8 +15,8 @@ import six
 import numpy as np
 import pandas as pd
 from io import StringIO
-from exa.util.units import Length
-from exa import TypedMeta
+from exatomic.exa.util.units import Length
+from exatomic.exa import TypedMeta
 from exatomic.base import sym2z
 from exatomic.algorithms.basis import lmap, enum_cartesian
 from exatomic.algorithms.numerical import dfac21
