@@ -1,8 +1,10 @@
-## -*- coding: utf-8 -*-
-#"""
-#Cell Packing Utilities
+# -*- coding: utf-8 -*-
+# Copyright (c) 2015-2022, Exa Analytics Development Team
+# Distributed under the terms of the Apache License 2.0
+"""
+Cell Packing Utilities
 ########################
-#"""
+"""
 #def cubic_cell_volume(mass, density):
 #    """
 #    Args:
