@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2015-2020, Exa Analytics Development Team
+# Copyright (c) 2015-2022, Exa Analytics Development Team
 # Distributed under the terms of the Apache License 2.0
 """
 Gaussian Output Editor
@@ -14,8 +14,8 @@ import six
 import numpy as np
 import pandas as pd
 from collections import defaultdict
-from exa import TypedMeta
-from exa.util.units import Length, Energy
+from exatomic.exa import TypedMeta
+from exatomic.exa.util.units import Length, Energy
 from .editor import Editor
 from exatomic.base import z2sym
 from exatomic.core.frame import compute_frame_from_atom
